/**
 * 高德地图
 * 
 * POI 类型下载 https://lbs.amap.com/api/webservice/guide/api/search/#around
 * 
 */
const amapLib = require('../lib/amap-wx');
const myAmapKey = '766411323b66f7e876f428d8a23aa83c'
const amap = new amapLib.AMapWX({ key: myAmapKey })

// key 值会被拿到 building 表中 组合为字段名
const POI_TYPES = [
  {
    key: 'Transport',
    label: '交通',
    types: ['150100', '150200', '150300', '150400', '150500', '150600'],
  },
  {
    key: 'Mall',
    label: '商业',
    types: ['060100', '060200', '060300', '060400', '060500', '060600',
            '060700', '060800', '060900', '061000', '061100', '061200',
            '061300', '061400', '080100', '080200', '080300', '080400',
            '080500', '080600'],
  },
  {
    key: 'Edu',
    label: '学校',
    types: ['141200'],
  },
  {
    key: 'Hospital',
    label: '医院',
    types: ['090100', '090200', '090300', '090400', '090500', '090600', '090700'],
  },
  {
    key: 'Bank',
    label: '银行',
    types: ['160100'],
  },
  {
    key: 'Restaurant',
    label: '餐饮',
    types: ['050100', '050200', '050300', '050400', '050500', '050600',
            '050700', '050800', '050900'],
  },
]

const getPrefix = str => str.substr(0, 4)

export function getPoiAround(params) {
  const {
    lng,
    lat
  } = params || {}

  return new Promise((resolve, reject) => {
    const querytypes = POI_TYPES.reduce((acc, item) => ([ ...acc, ...item.types ]), []).join('|')
    const location = `${lng},${lat}`
    const iconPath = undefined
    const iconPathSelected = undefined
    const resultList = []

    // 成功回调
    // https://lbs.amap.com/api/webservice/guide/api/search/#around
    const successCall = poiType => res => {
      resultList.push({
        key: poiType.key,
        label: poiType.label,
        poisData: res.poisData,
        markers: res.markers
      })

      if (resultList.length === POI_TYPES.length) {
        resolve(resultList)
      }
    }

    // 失败回调
    // https://lbs.amap.com/api/webservice/guide/tools/info/
    const failCall = poiType => info => {
      console.error(poiType, info)
      reject(info)
    }

    POI_TYPES.forEach((pt) => {
      const querytypes = pt.types.join('|')

      amap.getPoiAround({
        querytypes,
        location,
        iconPath,
        iconPathSelected,
        success: successCall(pt),
        fail: failCall(pt),
      })
    })
  })
}
